@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -64,10 +64,11 @@ public enum OXMFSubscriptionErrorMessage implements OXErrorMessage{
     /**
      * A parsing error occurred: %1$s.
      */
-    ParseException(Category.CODE_ERROR, 2, "Provide well-formed HTML.", "A parsing error occurred: %1$s."),
-    IOException(Category.SUBSYSTEM_OR_SERVICE_DOWN, 3, "Try again later.", "An IOException occurred: %1$s."),
-    HttpException(Category.SUBSYSTEM_OR_SERVICE_DOWN, 4, "Try again later.", "A HTTPException occurred: %1$s."), 
-    CAN_ONLY_POST_TO_EXTERNAL_SUBSCRIPTION_SOURCES(Category.INTERNAL_ERROR, 5, "Try again later.", "Can only post to external subscription soures")
+    ParseException(Category.CODE_ERROR, 2, "Provide well-formed HTML.", OXMFErrorStrings.PARSE_EXCEPTION),
+    IOException(Category.SUBSYSTEM_OR_SERVICE_DOWN, 3, "Try again later.", OXMFErrorStrings.IOException),
+    HttpException(Category.SUBSYSTEM_OR_SERVICE_DOWN, 4, "Try again later.", OXMFErrorStrings.HttpException), 
+    CAN_ONLY_POST_TO_EXTERNAL_SUBSCRIPTION_SOURCES(Category.INTERNAL_ERROR, 5,"Try again later.", OXMFErrorStrings.CAN_ONLY_POST_TO_EXTERNAL_SUBSCRIPTION_SOURCES),
+    ERROR_LOADING_SUBSCRIPTION(Category.SUBSYSTEM_OR_SERVICE_DOWN, 6, "Try again later.", OXMFErrorStrings.ERROR_LOADING_SUBSCRIPTION), 
     ;
     
     private Category category;
