@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -70,15 +70,16 @@ public class HTTPOXMFDataSource implements OXMFDataSource {
     private static final Log LOG = LogFactory.getLog(HTTPOXMFDataSource.class);
 
     public Reader getData(Subscription subscription) throws SubscriptionException {
+        String site = (String)subscription.getConfiguration().get(URL);
 
         try {
-            return HTTPToolkit.grab((String)subscription.getConfiguration().get(URL));
+            return HTTPToolkit.grab(site);
         } catch (HttpException e) {
             LOG.error(e.getMessage(), e);
-            throw OXMFSubscriptionErrorMessage.HttpException.create(e.getMessage(), e);
+            throw OXMFSubscriptionErrorMessage.ERROR_LOADING_SUBSCRIPTION.create(e, site);
         } catch (IOException e) {
             LOG.error(e.getMessage(), e);
-            throw OXMFSubscriptionErrorMessage.IOException.create(e.getMessage(), e);
+            throw OXMFSubscriptionErrorMessage.ERROR_LOADING_SUBSCRIPTION.create(e, site);
         }
 
     }
