@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -69,6 +69,7 @@ import com.openexchange.subscribe.microformats.OXMFParserFactoryService;
 import com.openexchange.subscribe.microformats.OXMFServiceRegistry;
 import com.openexchange.subscribe.microformats.OXMFSubscriptionErrorMessage;
 import com.openexchange.subscribe.microformats.datasources.HTTPOXMFDataSource;
+import com.openexchange.subscribe.microformats.objectparser.OXHCardParser;
 import com.openexchange.subscribe.microformats.parser.CybernekoOXMFFormParser;
 import com.openexchange.subscribe.microformats.parser.HTMLMicroformatParserFactory;
 import com.openexchange.subscribe.microformats.parser.OXMFFormParser;
@@ -120,6 +121,7 @@ public class SubcriptionServicesActivator implements BundleActivator {
         subscribeService.setSource(contactSubscriptionSource);
         subscribeService.addContainerElement("ox_contact");
         subscribeService.addPrefix("ox_");
+        subscribeService.addObjectParser(new OXHCardParser());
 
         contactSubscriptionSource.setSubscribeService(subscribeService);
 
