@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -146,7 +146,7 @@ public class HTMLMicroformatParser implements OXMFParser {
     private void parse(Node node, Map<String, String> element, List<String> attributeKeys) {
         String value = isImageElement(node)? getSrc(node) : isAnchorElement(node) ? getHref(node) : node.getTextContent();
         for (String key : attributeKeys) {
-            element.put(key, value);
+            element.put(key, value.trim());
         }
     }
 
